==> ejc-middlemeasurement-impl-3.0.0-20240229.075748-515-sources.jar: com/ejianc/business/middlemeasurement/vo/EngineermeasurementVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.EngineermeasurementdetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 工程计量台账
 *
 * @author generator
 *
 */
public class EngineermeasurementVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date reportingTime; // 报量时间
    private java.lang.String billCode; // 编号
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.math.BigDecimal actualCompletedThisPeriod; // 本期实际完成量
    private java.math.BigDecimal contractAmount; // 合同金额
    private java.math.BigDecimal cumulativeCompleted; // 累计实际完成量
    private java.math.BigDecimal cumulativeCompletedProportion; // 累计实际完成比例
    private java.math.BigDecimal currentBatch; // 本期批量
    private java.math.BigDecimal cumulativeBatch; // 累计批量
    private java.math.BigDecimal currentCollection; // 本期收款金额
    private java.math.BigDecimal cumulativeCollection; // 累计收款金额
    private java.math.BigDecimal accumulatedContractualReceivables;
    private java.lang.String reportingTimeShow; // 报量时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号
    private java.lang.Long originalId;
    private java.math.BigDecimal currentReceivables;//本期应收金额
    private Integer isSettlement; // 是否归集状态 0 未归集 1 归集
    private BigDecimal financeReportIncome; // 财务列报收入
    private BigDecimal confireRate; // 确权率

    private List<EngineermeasurementdetailVO> engineermeasurementdetailEntities = new ArrayList<>(); // 工程计量台账子表
    private List<EngineermeasurementPayeeDetailVO> engineermeasurementpayeedetailEntities = new ArrayList<>(); // 工程计量台账收款信息表
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 报量时间
     */
    public java.util.Date getReportingTime() {
        return reportingTime;
    }

    /**
     * 报量时间
     */
    public void setReportingTime(java.util.Date reportingTime) {
        this.reportingTime = reportingTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 本期实际完成量
     */
    public java.math.BigDecimal getActualCompletedThisPeriod() {
        return actualCompletedThisPeriod;
    }

    /**
     * 本期实际完成量
     */
    public void setActualCompletedThisPeriod(java.math.BigDecimal actualCompletedThisPeriod) {
        this.actualCompletedThisPeriod = actualCompletedThisPeriod;
    }
    /**
     * 合同金额
     */
    public java.math.BigDecimal getContractAmount() {
        return contractAmount;
    }

    /**
     * 合同金额
     */
    public void setContractAmount(java.math.BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    /**
     * 累计实际完成量
     */
    public java.math.BigDecimal getCumulativeCompleted() {
        return cumulativeCompleted;
    }

    /**
     * 累计实际完成量
     */
    public void setCumulativeCompleted(java.math.BigDecimal cumulativeCompleted) {
        this.cumulativeCompleted = cumulativeCompleted;
    }
    /**
     * 累计实际完成比例
     */
    public java.math.BigDecimal getCumulativeCompletedProportion() {
        return cumulativeCompletedProportion;
    }

    /**
     * 累计实际完成比例
     */
    public void setCumulativeCompletedProportion(java.math.BigDecimal cumulativeCompletedProportion) {
        this.cumulativeCompletedProportion = cumulativeCompletedProportion;
    }
    /**
     * 本期批量
     */
    public java.math.BigDecimal getCurrentBatch() {
        return currentBatch;
    }

    /**
     * 本期批量
     */
    public void setCurrentBatch(java.math.BigDecimal currentBatch) {
        this.currentBatch = currentBatch;
    }
    /**
     * 累计批量
     */
    public java.math.BigDecimal getCumulativeBatch() {
        return cumulativeBatch;
    }

    /**
     * 累计批量
     */
    public void setCumulativeBatch(java.math.BigDecimal cumulativeBatch) {
        this.cumulativeBatch = cumulativeBatch;
    }
    /**
     * 本期收款金额
     */
    public java.math.BigDecimal getCurrentCollection() {
        return currentCollection;
    }

    /**
     * 本期收款金额
     */
    public void setCurrentCollection(java.math.BigDecimal currentCollection) {
        this.currentCollection = currentCollection;
    }
    /**
     * 累计收款金额
     */
    public java.math.BigDecimal getCumulativeCollection() {
        return cumulativeCollection;
    }

    /**
     * 累计收款金额
     */
    public void setCumulativeCollection(java.math.BigDecimal cumulativeCollection) {
        this.cumulativeCollection = cumulativeCollection;
    }

     /**
      * 工程计量台账子表
      */
     public List<EngineermeasurementdetailVO> getEngineermeasurementdetailEntities() {
        return engineermeasurementdetailEntities;
     }

     /**
      * 工程计量台账子表
      */
     public void setEngineermeasurementdetailEntities(List<EngineermeasurementdetailVO> engineermeasurementdetailEntities) {
        this.engineermeasurementdetailEntities = engineermeasurementdetailEntities;
     }

    public String getReportingTimeShow() {
        return reportingTimeShow;
    }

    public void setReportingTimeShow(String reportingTimeShow) {
        this.reportingTimeShow = reportingTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public BigDecimal getAccumulatedContractualReceivables() {
        return accumulatedContractualReceivables;
    }

    public void setAccumulatedContractualReceivables(BigDecimal accumulatedContractualReceivables) {
        this.accumulatedContractualReceivables = accumulatedContractualReceivables;
    }

    public BigDecimal getCurrentReceivables() {
        return currentReceivables;
    }

    public void setCurrentReceivables(BigDecimal currentReceivables) {
        this.currentReceivables = currentReceivables;
    }

    public Integer getIsSettlement() {
        return isSettlement;
    }

    public void setIsSettlement(Integer isSettlement) {
        this.isSettlement = isSettlement;
    }

    public BigDecimal getFinanceReportIncome() {
        return financeReportIncome;
    }

    public void setFinanceReportIncome(BigDecimal financeReportIncome) {
        this.financeReportIncome = financeReportIncome;
    }

    public BigDecimal getConfireRate() {
        return confireRate;
    }

    public void setConfireRate(BigDecimal confireRate) {
        this.confireRate = confireRate;
    }

    public List<EngineermeasurementPayeeDetailVO> getEngineermeasurementpayeedetailEntities() {
        return engineermeasurementpayeedetailEntities;
    }

    public void setEngineermeasurementpayeedetailEntities(List<EngineermeasurementPayeeDetailVO> engineermeasurementpayeedetailEntities) {
        this.engineermeasurementpayeedetailEntities = engineermeasurementpayeedetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20240327.063749-530-sources.jar: com/ejianc/business/middlemeasurement/vo/EngineermeasurementVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.middlemeasurement.vo.EngineermeasurementdetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 工程计量台账
 *
 * @author generator
 *
 */
public class EngineermeasurementVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date reportingTime; // 报量时间
    private java.lang.String billCode; // 编号
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.math.BigDecimal actualCompletedThisPeriod; // 本期实际完成量
    private java.math.BigDecimal contractAmount; // 合同金额
    private java.math.BigDecimal cumulativeCompleted; // 累计实际完成量
    private java.math.BigDecimal cumulativeCompletedProportion; // 累计实际完成比例
    private java.math.BigDecimal currentBatch; // 本期批量
    private java.math.BigDecimal cumulativeBatch; // 累计批量
    private java.math.BigDecimal currentCollection; // 本期收款金额
    private java.math.BigDecimal cumulativeCollection; // 累计收款金额
    private java.math.BigDecimal accumulatedContractualReceivables;
    private java.lang.String reportingTimeShow; // 报量时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号
    private java.lang.Long originalId;
    private java.math.BigDecimal currentReceivables;//本期应收金额
    private Integer isSettlement; // 是否归集状态 0 未归集 1 归集
    private BigDecimal financeReportIncome; // 财务列报收入
    private BigDecimal confireRate; // 确权率

    private List<EngineermeasurementdetailVO> engineermeasurementdetailEntities = new ArrayList<>(); // 工程计量台账子表
    private List<EngineermeasurementPayeeDetailVO> engineermeasurementpayeedetailEntities = new ArrayList<>(); // 工程计量台账收款信息表


    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date projectCreateTime; // 项目创建日期
    private Integer orgStatusOrder; // 二级组织排序

    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-incontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 报量时间
     */
    public java.util.Date getReportingTime() {
        return reportingTime;
    }

    /**
     * 报量时间
     */
    public void setReportingTime(java.util.Date reportingTime) {
        this.reportingTime = reportingTime;
    }
    /**
     * 编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 本期实际完成量
     */
    public java.math.BigDecimal getActualCompletedThisPeriod() {
        return actualCompletedThisPeriod;
    }

    /**
     * 本期实际完成量
     */
    public void setActualCompletedThisPeriod(java.math.BigDecimal actualCompletedThisPeriod) {
        this.actualCompletedThisPeriod = actualCompletedThisPeriod;
    }
    /**
     * 合同金额
     */
    public java.math.BigDecimal getContractAmount() {
        return contractAmount;
    }

    /**
     * 合同金额
     */
    public void setContractAmount(java.math.BigDecimal contractAmount) {
        this.contractAmount = contractAmount;
    }
    /**
     * 累计实际完成量
     */
    public java.math.BigDecimal getCumulativeCompleted() {
        return cumulativeCompleted;
    }

    /**
     * 累计实际完成量
     */
    public void setCumulativeCompleted(java.math.BigDecimal cumulativeCompleted) {
        this.cumulativeCompleted = cumulativeCompleted;
    }
    /**
     * 累计实际完成比例
     */
    public java.math.BigDecimal getCumulativeCompletedProportion() {
        return cumulativeCompletedProportion;
    }

    /**
     * 累计实际完成比例
     */
    public void setCumulativeCompletedProportion(java.math.BigDecimal cumulativeCompletedProportion) {
        this.cumulativeCompletedProportion = cumulativeCompletedProportion;
    }
    /**
     * 本期批量
     */
    public java.math.BigDecimal getCurrentBatch() {
        return currentBatch;
    }

    /**
     * 本期批量
     */
    public void setCurrentBatch(java.math.BigDecimal currentBatch) {
        this.currentBatch = currentBatch;
    }
    /**
     * 累计批量
     */
    public java.math.BigDecimal getCumulativeBatch() {
        return cumulativeBatch;
    }

    /**
     * 累计批量
     */
    public void setCumulativeBatch(java.math.BigDecimal cumulativeBatch) {
        this.cumulativeBatch = cumulativeBatch;
    }
    /**
     * 本期收款金额
     */
    public java.math.BigDecimal getCurrentCollection() {
        return currentCollection;
    }

    /**
     * 本期收款金额
     */
    public void setCurrentCollection(java.math.BigDecimal currentCollection) {
        this.currentCollection = currentCollection;
    }
    /**
     * 累计收款金额
     */
    public java.math.BigDecimal getCumulativeCollection() {
        return cumulativeCollection;
    }

    /**
     * 累计收款金额
     */
    public void setCumulativeCollection(java.math.BigDecimal cumulativeCollection) {
        this.cumulativeCollection = cumulativeCollection;
    }

     /**
      * 工程计量台账子表
      */
     public List<EngineermeasurementdetailVO> getEngineermeasurementdetailEntities() {
        return engineermeasurementdetailEntities;
     }

     /**
      * 工程计量台账子表
      */
     public void setEngineermeasurementdetailEntities(List<EngineermeasurementdetailVO> engineermeasurementdetailEntities) {
        this.engineermeasurementdetailEntities = engineermeasurementdetailEntities;
     }

    public String getReportingTimeShow() {
        return reportingTimeShow;
    }

    public void setReportingTimeShow(String reportingTimeShow) {
        this.reportingTimeShow = reportingTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    public BigDecimal getAccumulatedContractualReceivables() {
        return accumulatedContractualReceivables;
    }

    public void setAccumulatedContractualReceivables(BigDecimal accumulatedContractualReceivables) {
        this.accumulatedContractualReceivables = accumulatedContractualReceivables;
    }

    public BigDecimal getCurrentReceivables() {
        return currentReceivables;
    }

    public void setCurrentReceivables(BigDecimal currentReceivables) {
        this.currentReceivables = currentReceivables;
    }

    public Integer getIsSettlement() {
        return isSettlement;
    }

    public void setIsSettlement(Integer isSettlement) {
        this.isSettlement = isSettlement;
    }

    public BigDecimal getFinanceReportIncome() {
        return financeReportIncome;
    }

    public void setFinanceReportIncome(BigDecimal financeReportIncome) {
        this.financeReportIncome = financeReportIncome;
    }

    public BigDecimal getConfireRate() {
        return confireRate;
    }

    public void setConfireRate(BigDecimal confireRate) {
        this.confireRate = confireRate;
    }

    public List<EngineermeasurementPayeeDetailVO> getEngineermeasurementpayeedetailEntities() {
        return engineermeasurementpayeedetailEntities;
    }

    public void setEngineermeasurementpayeedetailEntities(List<EngineermeasurementPayeeDetailVO> engineermeasurementpayeedetailEntities) {
        this.engineermeasurementpayeedetailEntities = engineermeasurementpayeedetailEntities;
    }
}
